% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/separate_cifti.R
\name{separate_cifti_wrapper}
\alias{separate_cifti_wrapper}
\title{\code{separate_cifti} wrapper}
\usage{
separate_cifti_wrapper(
  cifti_fname,
  brainstructures = "existing",
  ROI_brainstructures = "all",
  sep_fnames = NULL,
  write_dir = NULL
)
}
\arguments{
\item{cifti_fname}{File path to a CIFTI file (ending in ".d*.nii").}

\item{brainstructures}{Character vector indicating which brain structure(s)
to read in: \code{"left"} (left cortex), \code{"right"} (right cortex)
and/or \code{"subcortical"} (subcortex and cerebellum). Can also be
\code{"all"} (read all three brain structures), or \code{"existing"}
(read all brain structures in the file). Default: \code{"existing"}.

If a brain structure is indicated but does not exist, a warning will be
raised and that brain structure will be skipped.}

\item{ROI_brainstructures}{Character vector indicating which ROIs should be
obtained. \code{NULL} (default) to not get any ROIs. Otherwise, this should
be a subset of the \code{brainstructures} argument.

ROIs are typically the medial wall masks for the left and right cortex, and
the subcortical mask for the subcortex.}

\item{sep_fnames}{Where to write the separated files (override
their default file names). This is a named list
where each entry's name is a file type label, and each entry's value
is a file name indicating where to write the corresponding separated file.
The recognized file type labels are: "cortexL", "cortexR",
"ROIcortexL", "ROIcortexR", "subcortVol", and "subcortLabs".

Entry values can be \code{NULL}, in which case a default file name will be
used: see \code{\link{cifti_component_suffix}}. Default file names
will also be used for files that need to be separated/written but without a
corresponding entry in \code{sep_fnames}.

Entries in \code{sep_fnames} will be ignored if they are not needed
based on \code{[ROI_]brainstructures}. For example, if
\code{brainstructures="left"}, then \code{sep_fnames$cortexR} will be
ignored if specified.

The \code{write_dir} argument can be used to place each separated file in
the same directory.}

\item{write_dir}{Where should the separate files be placed? \code{NULL}
(default) will write them to the current working directory.

\code{write_dir} must already exist, or an error will occur.}
}
\value{
The return value of the \code{separate_cifti} call
}
\description{
Calls \code{separate_cifti} using the file names listed in the
argument \code{sep_fnames}.
}
\details{
Currently used by \code{read_cifti} and \code{resample_cifti}.
}
\keyword{internal}
